==> citrus-spring-4.0.2-sources.jar: org/citrusframework/model/testcase/core/TransformModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für TransformActionType complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType name="TransformActionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <choice>
 *           <element name="xml-data" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           <element name="xml-resource">
 *             <complexType>
 *               <complexContent>
 *                 <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                   <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 </restriction>
 *               </complexContent>
 *             </complexType>
 *           </element>
 *         </choice>
 *         <choice>
 *           <element name="xslt-data" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           <element name="xslt-resource">
 *             <complexType>
 *               <complexContent>
 *                 <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                   <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 </restriction>
 *               </complexContent>
 *             </complexType>
 *           </element>
 *         </choice>
 *       </sequence>
 *       <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TransformActionType", propOrder = {
    "description",
    "xmlResource",
    "xmlData",
    "xsltResource",
    "xsltData"
})
@XmlRootElement(name = "transform")
public class TransformModel {

    protected String description;
    @XmlElement(name = "xml-resource")
    protected TransformModel.XmlResource xmlResource;
    @XmlElement(name = "xml-data")
    protected String xmlData;
    @XmlElement(name = "xslt-resource")
    protected TransformModel.XsltResource xsltResource;
    @XmlElement(name = "xslt-data")
    protected String xsltData;
    @XmlAttribute(name = "variable", required = true)
    protected String variable;

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Ruft den Wert der xmlResource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TransformModel.XmlResource }
     *     
     */
    public TransformModel.XmlResource getXmlResource() {
        return xmlResource;
    }

    /**
     * Legt den Wert der xmlResource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TransformModel.XmlResource }
     *     
     */
    public void setXmlResource(TransformModel.XmlResource value) {
        this.xmlResource = value;
    }

    /**
     * Ruft den Wert der xmlData-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getXmlData() {
        return xmlData;
    }

    /**
     * Legt den Wert der xmlData-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setXmlData(String value) {
        this.xmlData = value;
    }

    /**
     * Ruft den Wert der xsltResource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TransformModel.XsltResource }
     *     
     */
    public TransformModel.XsltResource getXsltResource() {
        return xsltResource;
    }

    /**
     * Legt den Wert der xsltResource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TransformModel.XsltResource }
     *     
     */
    public void setXsltResource(TransformModel.XsltResource value) {
        this.xsltResource = value;
    }

    /**
     * Ruft den Wert der xsltData-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getXsltData() {
        return xsltData;
    }

    /**
     * Legt den Wert der xsltData-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setXsltData(String value) {
        this.xsltData = value;
    }

    /**
     * Ruft den Wert der variable-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVariable() {
        return variable;
    }

    /**
     * Legt den Wert der variable-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVariable(String value) {
        this.variable = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class XmlResource {

        @XmlAttribute(name = "file", required = true)
        protected String file;
        @XmlAttribute(name = "charset")
        protected String charset;

        /**
         * Ruft den Wert der file-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getFile() {
            return file;
        }

        /**
         * Legt den Wert der file-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setFile(String value) {
            this.file = value;
        }

        /**
         * Ruft den Wert der charset-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCharset() {
            return charset;
        }

        /**
         * Legt den Wert der charset-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCharset(String value) {
            this.charset = value;
        }

    }


    /**
     * <p>Java-Klasse für anonymous complex type.
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class XsltResource {

        @XmlAttribute(name = "file", required = true)
        protected String file;
        @XmlAttribute(name = "charset")
        protected String charset;

        /**
         * Ruft den Wert der file-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getFile() {
            return file;
        }

        /**
         * Legt den Wert der file-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setFile(String value) {
            this.file = value;
        }

        /**
         * Ruft den Wert der charset-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCharset() {
            return charset;
        }

        /**
         * Legt den Wert der charset-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCharset(String value) {
            this.charset = value;
        }

    }

}

==> citrus-spring-4.1.0-sources.jar: org/citrusframework/model/testcase/core/TransformModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.core;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für TransformActionType complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType name="TransformActionType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://www.citrusframework.org/schema/testcase}description" minOccurs="0"/>
 *         <choice>
 *           <element name="xml-data" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           <element name="xml-resource">
 *             <complexType>
 *               <complexContent>
 *                 <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                   <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 </restriction>
 *               </complexContent>
 *             </complexType>
 *           </element>
 *         </choice>
 *         <choice>
 *           <element name="xslt-data" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *           <element name="xslt-resource">
 *             <complexType>
 *               <complexContent>
 *                 <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                   <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                   <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                 </restriction>
 *               </complexContent>
 *             </complexType>
 *           </element>
 *         </choice>
 *       </sequence>
 *       <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TransformActionType", propOrder = {
    "description",
    "xmlResource",
    "xmlData",
    "xsltResource",
    "xsltData"
})
@XmlRootElement(name = "transform")
public class TransformModel {

    protected String description;
    @XmlElement(name = "xml-resource")
    protected TransformModel.XmlResource xmlResource;
    @XmlElement(name = "xml-data")
    protected String xmlData;
    @XmlElement(name = "xslt-resource")
    protected TransformModel.XsltResource xsltResource;
    @XmlElement(name = "xslt-data")
    protected String xsltData;
    @XmlAttribute(name = "variable", required = true)
    protected String variable;

    /**
     * Ruft den Wert der description-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDescription() {
        return description;
    }

    /**
     * Legt den Wert der description-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDescription(String value) {
        this.description = value;
    }

    /**
     * Ruft den Wert der xmlResource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TransformModel.XmlResource }
     *     
     */
    public TransformModel.XmlResource getXmlResource() {
        return xmlResource;
    }

    /**
     * Legt den Wert der xmlResource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TransformModel.XmlResource }
     *     
     */
    public void setXmlResource(TransformModel.XmlResource value) {
        this.xmlResource = value;
    }

    /**
     * Ruft den Wert der xmlData-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getXmlData() {
        return xmlData;
    }

    /**
     * Legt den Wert der xmlData-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setXmlData(String value) {
        this.xmlData = value;
    }

    /**
     * Ruft den Wert der xsltResource-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link TransformModel.XsltResource }
     *     
     */
    public TransformModel.XsltResource getXsltResource() {
        return xsltResource;
    }

    /**
     * Legt den Wert der xsltResource-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link TransformModel.XsltResource }
     *     
     */
    public void setXsltResource(TransformModel.XsltResource value) {
        this.xsltResource = value;
    }

    /**
     * Ruft den Wert der xsltData-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getXsltData() {
        return xsltData;
    }

    /**
     * Legt den Wert der xsltData-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setXsltData(String value) {
        this.xsltData = value;
    }

    /**
     * Ruft den Wert der variable-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVariable() {
        return variable;
    }

    /**
     * Legt den Wert der variable-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVariable(String value) {
        this.variable = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.</p>
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class XmlResource {

        @XmlAttribute(name = "file", required = true)
        protected String file;
        @XmlAttribute(name = "charset")
        protected String charset;

        /**
         * Ruft den Wert der file-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getFile() {
            return file;
        }

        /**
         * Legt den Wert der file-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setFile(String value) {
            this.file = value;
        }

        /**
         * Ruft den Wert der charset-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCharset() {
            return charset;
        }

        /**
         * Legt den Wert der charset-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCharset(String value) {
            this.charset = value;
        }

    }


    /**
     * <p>Java-Klasse für anonymous complex type.</p>
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <attribute name="file" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *       <attribute name="charset" type="{http://www.w3.org/2001/XMLSchema}string" />
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "")
    public static class XsltResource {

        @XmlAttribute(name = "file", required = true)
        protected String file;
        @XmlAttribute(name = "charset")
        protected String charset;

        /**
         * Ruft den Wert der file-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getFile() {
            return file;
        }

        /**
         * Legt den Wert der file-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setFile(String value) {
            this.file = value;
        }

        /**
         * Ruft den Wert der charset-Eigenschaft ab.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getCharset() {
            return charset;
        }

        /**
         * Legt den Wert der charset-Eigenschaft fest.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setCharset(String value) {
            this.charset = value;
        }

    }

}
